@@ -6,7 +6,7 @@ python version.
 
 from sys import version_info
 
-MIN_PYTHON_VER = (3, 6, 7)
+MIN_PYTHON_VER = (3, 7)
 PYTHON_VER_SPLIT = (3, 9)
 
 assert version_info >= MIN_PYTHON_VER
